Header processing — MSUMastro toolbox 0.1 documentation

# Header processing

## Introduction

The msumastro.header_processing subpackage contains classes and functions that do the work of modifying headers. There are several scripts for Automated header processing and Manual header processing provided to carry out the most common types of headers processing.

## Reference/API

### msumastro.header_processing.fitskeyword Module

#### Classes

`FITSKeyword`([name, value, comment, synonyms]) | Represents a FITS keyword, which may have several synonyms.

### msumastro.header_processing.astrometry Module

#### Functions

`call_astrometry`(filename[, sextractor, ...]) | Wrapper around astrometry.net solve-field.
`add_astrometry`(filename[, overwrite, ...]) | Add WCS headers to FITS file using astrometry.net :Parameters: overwrite : bool, optional Set `True` to overwrite the original file.

### msumastro.header_processing.feder Module

#### Classes

`FederSite`() | The Feder Observatory site.
`ImageSoftware`(name[, fits_name, ...]) | Represents software that takes images at telescope.
`Instrument`(name[, fits_names, rows, ...]) | Telescope instrument with simple properties.
`ApogeeAltaU9`() | The Apogee Alta U9
`MaximDL4`() | Represents MaximDL version 4, all sub-versions
`MaximDL5`() | Represents MaximDL version 5, all sub-versions.

### msumastro.header_processing.patchers Module

#### Functions

`IRAF_image_type`(image_type) | Convert MaximDL default image type names to IRAF :Parameters: image_type : str Value of the FITS header keyword IMAGETYP; acceptable values are below in Notes.
`add_object_info`([directory, object_list, ...]) | Add object information to FITS files that contain pointing information given a list of objects.
`add_object_pos_airmass`(header[, history]) | Add object information, such as RA/Dec and airmass.
`add_overscan_header`(header[, history]) | Add overscan information to a FITS header.
`add_ra_dec_from_object_name`([directory, ...]) | Add RA/Dec to FITS file that has object name but no pointing.
`add_time_info`(header[, history]) | Add JD, MJD, LST to FITS header :Parameters: header : astropy..io.fits.Header FITS header to be modified.
`change_imagetype_to_IRAF`(header[, history]) | Change IMAGETYP to default used by IRAF :Parameters: header : astropy.io.fits.Header Header object in which image type is to be changed.
`compare_data_in_fits`(file1, file2) | Compare the image data in two FITS files.
`fix_int16_images`([directory, new_file_ext]) | Repair unsigned int16 images saved as signed int16.
`get_software_name`(header[, file_name, ...]) | Determine the name of the software that created FITIS header :Parameters: header : astropy.io.fits Header Header from a FITS extension/hdu file_name : str, optional Name of the file containing this header; used to add information to error/warning messages.
`history`(function[, mode, time]) | Construct nicely formatted start/end markers in FITS history.
`patch_headers`([dir, new_file_ext, ...]) | Add minimal information to Feder FITS headers.
`purge_bad_keywords`(header[, history, force, ...]) | Remove keywords from FITS header that may be incorrect :Parameters: header : astropy.io.fits.Header Header from which the bad keywords (as defined by the software that recorded the image) should be purged.
`read_object_list`([dir, input_list]) | Read a list of objects from a text file.